@@ -88,7 +88,7 @@ void Klass::openLoop(Tree recsymbol, const string& size)
     // cerr << "\nOPEN REC LOOP(" << *recsymbol << ", " << size << ") ----> " << fTopLoop << endl;
 }
 
-void Klass::listAllLoopProperties(Tree sig, set<Loop*>& L, set<Tree, CTreeComparator>& visited)
+void Klass::listAllLoopProperties(Tree sig, set<Loop*>& L, set<Tree>& visited)
 {
     if (visited.count(sig) == 0) {
         visited.insert(sig);
@@ -115,8 +115,8 @@ void Klass::closeLoop(Tree sig)
     faustassert(fTopLoop);
 
     // fix the missing dependencies
-    set<Loop*>                 L;
-    set<Tree, CTreeComparator> V;
+    set<Loop*> L;
+    set<Tree>  V;
     listAllLoopProperties(sig, L, V);
     for (Loop* l : L) {
         fTopLoop->fBackwardLoopDependencies.insert(l);
