@@ -138,6 +138,10 @@
 #include "vhdl/vhdl_producer.hh"
 #endif
 
+#ifdef SDF3_BUILD
+#include "sdf3/signal2SDF.hh"
+#endif
+
 using namespace std;
 
 /****************************************************************
@@ -477,9 +481,10 @@ static void compileCodebox(Tree signals, int numInputs, int numOutputs, ostream*
     // FIR is generated with internal real instead of FAUSTFLOAT (see IB::genBasicTyped)
     gGlobal->gFAUSTFLOAT2Internal = true;
 
-    // "one sample control" model by default;
-    gGlobal->gOneSampleControl = true;
-    gGlobal->gNeedManualPow = false;  // Standard pow function will be used in pow(x,y) when y in an
+    // "one sample inputs/outputs" model by default
+    gGlobal->gOneSampleIO = true;
+    // Standard pow function will be used in pow(x,y) when y in an integer
+    gGlobal->gNeedManualPow = false;
 
     gContainer =
         CodeboxCodeContainer::createContainer(gGlobal->gClassName, numInputs, numOutputs, out);
@@ -522,6 +527,7 @@ static void compileCPP(Tree signals, int numInputs, int numOutputs, ostream* out
 static void compileOCPP(Tree signals, int numInputs, int numOutputs)
 {
 #ifdef OCPP_BUILD
+    gGlobal->gEnableFlag = false;  // enable not supported in current `-lang ocpp` backend
     if (gGlobal->gSchedulerSwitch) {
         gOldComp = new SchedulerCompiler(gGlobal->gClassName, gGlobal->gSuperClassName, numInputs,
                                          numOutputs);
@@ -723,10 +729,10 @@ static void compileCmajor(Tree signals, int numInputs, int numOutputs, ostream*
     // FIR is generated with internal real instead of FAUSTFLOAT (see IB::genBasicTyped)
     gGlobal->gFAUSTFLOAT2Internal = true;
 
-    // "one sample control" model by default;
-    gGlobal->gOneSampleControl = true;
-    gGlobal->gNeedManualPow =
-        false;  // Standard pow function will be used in pow(x,y) when y in an integer
+    // "one sample inputs/outputs" model by default
+    gGlobal->gOneSampleIO = true;
+    // Standard pow function will be used in pow(x,y) when y in an integer
+    gGlobal->gNeedManualPow = false;
 
     gContainer =
         CmajorCodeContainer::createContainer(gGlobal->gClassName, numInputs, numOutputs, out);
@@ -871,6 +877,20 @@ static void compileVhdl(Tree signals, int numInputs, int numOutputs, ostream* ou
 #endif
 }
 
+static void compileSdf3(Tree signals, ostream* out)
+{
+#ifdef SDF3_BUILD
+    signals = simplifyToNormalForm(signals);
+    Signal2SDF V;
+    V.sigToSDF(signals, *out);
+    if (gUseCout) {
+        cout << dynamic_cast<ostringstream*>(out)->str();
+    }
+#else
+    throw faustexception("ERROR : -lang sdf3 not supported since SDF3 backend is not built\n");
+#endif
+}
+
 static void generateCodeAux1(unique_ptr<ostream>& helpers, unique_ptr<ifstream>& enrobage,
                              unique_ptr<ostream>& dst)
 {
@@ -955,6 +975,9 @@ static void generateCodeAux1(unique_ptr<ostream>& helpers, unique_ptr<ifstream>&
             }
         }
     }
+
+    // Possibly generate JSON
+    gContainer->generateJSONFile();
 }
 
 #ifdef OCPP_BUILD
@@ -1082,6 +1105,10 @@ static void generateCode(Tree signals, int numInputs, int numOutputs, bool gener
         compileVhdl(signals, numInputs, numOutputs, gDst.get());
         // VHDL does not create a compiler, code is already generated here.
         return;
+    } else if (startWith(gGlobal->gOutputLang, "sdf3")) {
+        compileSdf3(signals, gDst.get());
+        // SDF3 does not create a compiler, code is already generated here.
+        return;
     } else {
         stringstream error;
         error << "ERROR : cannot find backend for "
