@@ -165,7 +165,7 @@ static Tree normalizeLabel(Tree label, Tree path)
     if (isList(label)) {
         return cons(label, path);
     } else {
-        Sym  s      = 0;
+        Sym  s;
         bool is_sym = isSym(label->node(), &s);
         faustassert(is_sym);
         return concatPath(label2path(name(s)), path);
@@ -243,4 +243,4 @@ bool matchGroup(Tree gpath, Tree lpath, Tree& rpath)
     } else {
         return false;
     }
-}
\ No newline at end of file
+}
