@@ -124,6 +124,7 @@ faustgen::faustgen(t_symbol* sym, long ac, t_atom* argv)
 // Called upon deleting the object inside the patcher
 faustgen::~faustgen()
 {
+    fDSPfactory->lock_audio();
     free_dsp();
     
     if (fEditor) {
@@ -133,6 +134,7 @@ faustgen::~faustgen()
     
     fDSPfactory->remove_instance(this);    
     fMidiHandler.stopMidi();
+    fDSPfactory->unlock_audio();
 }
 
 void faustgen::assist(void* b, long msg, long a, char* dst)
@@ -519,11 +521,7 @@ void faustgen::dblclick(long inlet)
             
         case 1:
             // Open the text editor to allow the user to input Faust sourcecode
-            if (m_is_mc && sys_getdspobjdspstate((t_object*)&m_ob)) {
-                post("WARNING : in multichannels mode, the editor cannot be safely used while running !");
-            } else {
-                display_dsp_source();
-            }
+            display_dsp_source();
             break;
             
         case 2:
@@ -594,9 +592,11 @@ inline void faustgen::perform(int vs, t_sample** inputs, long numins, t_sample**
         // Has to be tested again when the lock has been taken...
         if (fDSP) {
             if (m_is_mc) {
-                // Not RT but simpler...
-                if (!fMCDSP) {
+                // Not RT but simpler: adapt channel layout at first cycle or when the connected layout changes
+                if (!fMCDSP || (fMCDSP && ((numins != fMCDSP->getNumInputs() || numouts != fMCDSP->getNumOutputs())))) {
+                    delete fMCDSP;
                     fMCDSP = new dsp_adapter(fDSP, numins, fDSP->getNumOutputs(), 4096, false);
+                    std::cout << "new dsp_adapter " << numins << " " << fDSP->getNumOutputs() << std::endl;
                 }
                 fMCDSP->compute(vs, reinterpret_cast<FAUSTFLOAT**>(inputs), reinterpret_cast<FAUSTFLOAT**>(outputs));
             } else {
@@ -794,10 +794,11 @@ void faustgen::create_jsui()
  *
  * mess : "start" or "stop" message
  */
+
+/*
 void faustgen::dsp_status(const char* mess)
 {
     t_pxobject* dac = nullptr;
-    
     if ((dac = check_dac())) {
         t_atom msg[1];
         atom_setsym(msg, gensym(mess));
@@ -806,6 +807,12 @@ void faustgen::dsp_status(const char* mess)
         object_method(gensym("dsp")->s_thing, gensym(mess));
     }
 }
+*/
+
+void faustgen::dsp_status(const char* mess)
+{
+    object_method(gensym("dsp")->s_thing, gensym(mess));
+}
 
 /**
  * Set the object mute state.
@@ -851,7 +858,7 @@ extern "C" void ext_main(void* r)
     
     post("faustgen~/mc.faustgen~ v%s (sample = 64 bits code = %s)", FAUSTGEN_VERSION, getCodeSize());
     post("LLVM powered Faust embedded compiler v%s", getCLibFaustVersion());
-    post("Copyright (c) 2012-2024 Grame");
+    post("Copyright (c) 2012-2025 Grame");
     
     // Start 'libfaust' in multi-thread safe mode
     startMTDSPFactories();
